@@ -19,10 +19,6 @@ import nwdiag.drawer
 import nwdiag.parser
 from blockdiag.utils.bootstrap import Application
 
-# for compatibility
-from blockdiag.utils.bootstrap import create_fontmap, detectfont
-(create_fontmap, detectfont)
-
 
 class NwdiagApp(Application):
     module = nwdiag
