@@ -56,7 +56,7 @@ class ParseException(Exception):
     pass
 
 
-def tokenize(str):
+def tokenize(string):
     'str -> Sequence(Token)'
     specs = [
         ('Comment', (r'/\*(.|[\r\n])*?\*/', MULTILINE)),
@@ -64,6 +64,7 @@ def tokenize(str):
         ('NL',      (r'[\r\n]+',)),
         ('Space',   (r'[ \t\r\n]+',)),
         ('RackItem', (r':[^\r\n\[]+',)),
+        ('NonnumRackItem', (r'[\*\-]\s*[^\r\n\[]+',)),
         ('Units',   (r'([0-9]+U|[0-9]+(?:\.[0-9]+)?(A|kg))',)),
         ('Number',  (r'[0-9]+',)),
         ('Name',    (ur'[A-Za-z_0-9\u0080-\uffff]'
@@ -73,7 +74,7 @@ def tokenize(str):
     ]
     useless = ['Comment', 'NL', 'Space']
     t = make_tokenizer(specs)
-    return [x for x in t(str) if x.type not in useless]
+    return [x for x in t(string) if x.type not in useless]
 
 
 def parse(seq):
@@ -84,29 +85,39 @@ def parse(seq):
     n = lambda s: a(Token('Name', s)) >> tokval
     op = lambda s: a(Token('Op', s)) >> tokval
     op_ = lambda s: skip(op(s))
-    id = some(lambda t: t.type in ['Name', 'Number', 'String', 'Units']
-              ).named('id') >> tokval
+    _id = some(lambda t: t.type in ['Name', 'Number', 'String', 'Units']
+               ).named('id') >> tokval
     number = some(lambda t: t.type == 'Number').named('number') >> tokval
     rackitem = some(lambda t: t.type == 'RackItem').named('rackitem') >> tokval
+    nonnum_rackitem = (some(lambda t: t.type == 'NonnumRackItem').
+                       named('nonnum_rackitem') >> tokval)
     make_graph_attr = lambda args: DefAttrs(u'graph', [Attr(*args)])
 
-    racklabel = lambda text: re.sub("^:\s*(.*?)\s*;?$", "\\1", text)
+    racklabel = lambda text: re.sub("^.\s*(.*?)\s*;?$", "\\1", text)
     make_rackitem = lambda no, text, attr: RackItem(no, racklabel(text), attr)
+    make_rackitem2 = lambda text, attr: RackItem(None, racklabel(text), attr)
 
     a_list = (
-        id +
-        maybe(op_('=') + id) +
+        _id +
+        maybe(op_('=') + _id) +
         skip(maybe(op(',')))
         >> unarg(Attr))
     attr_list = (
         many(op_('[') + many(a_list) + op_(']'))
         >> flatten)
-    graph_attr = id + op_('=') + id >> make_graph_attr
-    rackitem_stmt = (
+    graph_attr = _id + op_('=') + _id >> make_graph_attr
+    numbered_rackitem_stmt = (
         number +
         rackitem +
         attr_list
         >> unarg(make_rackitem))
+    nonnumbered_rackitem_stmt = (
+        nonnum_rackitem +
+        attr_list
+        >> unarg(make_rackitem2))
+    rackitem_stmt = (
+        numbered_rackitem_stmt
+        | nonnumbered_rackitem_stmt)
 
     # rack definition
     rack_stmt = (
@@ -117,7 +128,7 @@ def parse(seq):
     rack_stmt_list = many(rack_stmt + skip(maybe(op(';'))))
     rack = (
         skip(n('rack')) +
-        maybe(id) +
+        maybe(_id) +
         op_('{') +
         rack_stmt_list +
         op_('}')
@@ -126,7 +137,7 @@ def parse(seq):
     # plugin definition
     plugin_stmt = (
         skip(n('plugin')) +
-        id +
+        _id +
         attr_list
         >> unarg(AttrPlugin))
 
@@ -139,7 +150,7 @@ def parse(seq):
     stmt_list = many(stmt + skip(maybe(op(';'))))
     graph = (
         maybe(n('diagram') | n('rackdiag')) +
-        maybe(id) +
+        maybe(_id) +
         op_('{') +
         stmt_list +
         op_('}')
@@ -156,8 +167,8 @@ def sort_tree(tree):
         else:
             return 2
 
-    def compare(a, b):
-        return cmp(weight(a), weight(b))
+    def compare(node1, node2):
+        return cmp(weight(node1), weight(node2))
 
     if hasattr(tree, 'stmts'):
         tree.stmts.sort(compare)
@@ -179,5 +190,5 @@ def parse_string(string):
 
 
 def parse_file(path):
-    input = codecs.open(path, 'r', 'utf-8').read()
-    return parse_string(input)
+    code = codecs.open(path, 'r', 'utf-8').read()
+    return parse_string(code)
